@@ -1,5 +1,5 @@
 package Text::Hogan;
-$Text::Hogan::VERSION = '2.00';
+$Text::Hogan::VERSION = '2.02';
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ Text::Hogan - A mustache templating engine statement-for-statement cloned from h
 
 =head1 VERSION
 
-version 2.00
+version 2.02
 
 =head1 DESCRIPTION
 
@@ -80,10 +80,12 @@ Initial translation by Alex Balhatchet (alex@balhatchet.net)
 
 Further improvements from:
 
-Yanick Champoux
+Ed Freyfogle
 Mohammad S Anwar
-Tony Finch
-Tom Hukins
 Ricky Morse
+Jerrad Pierce
+Tom Hukins
+Tony Finch
+Yanick Champoux
 
 =cut
